searchData={"items":[{"type":"module","title":"Thumbhash","doc":"Implementation of ThumbHash in Elixir","ref":"Thumbhash.html"},{"type":"function","title":"Thumbhash.rgba_to_thumb_hash/3","doc":"Encodes an RGBA image to a ThumbHash.","ref":"Thumbhash.html#rgba_to_thumb_hash/3"},{"type":"function","title":"Note - Thumbhash.rgba_to_thumb_hash/3","doc":"- `w` and `h` cannot exceed `100`\n  - `rgba` is required to be an `:array.array()`\n\nReturns a binary of hash.","ref":"Thumbhash.html#rgba_to_thumb_hash/3-note"},{"type":"extras","title":"Thumbhash","doc":"# Thumbhash\n\nThis is a pure Elixir implementation of [ThumbHash](https://github.com/evanw/thumbhash).","ref":"readme.html"},{"type":"extras","title":"Current status - Thumbhash","doc":"Which only implements the encoding-related APIs, without decoding functionality. **During the alpha release phase, the API may undergo incompatible changes.**","ref":"readme.html#current-status"},{"type":"extras","title":"Preview - Thumbhash","doc":"| File       |             Original             |                  Placeholder                  | base64                         |\n| ---------- | :------------------------------: | :-------------------------------------------: | ------------------------------ |\n| flower.jpg | ![Origin image](/img/flower.jpg) | ![ThumbHash image](/img/flower-thumbhash.png) | `k0oGLQaSVsN0BVhn2oq2Z5SQUQcZ` |","ref":"readme.html#preview"},{"type":"extras","title":"Installation - Thumbhash","doc":"Add Thumbhash to your `mix.exs` dependencies:\n\n```elixir\ndef deps do\n  [\n    {:thumbhash, \"~> 0.1.0-alpha.0\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Thumbhash","doc":"Example (use [`Image`](https://github.com/elixir-image/image) to get image data):\n\n```elixir\nimage = Image.open!(Path.join(\"img\", \"flower.jpg\"))\n\nrgba =\n  if Image.has_alpha?(image) do\n    {:ok, data} = Vix.Vips.Image.write_to_binary(image)\n    :binary.bin_to_list(data)\n  else\n    image = Image.add_alpha!(image, 255) # If there is no alpha channel, add a fixed value of 255.\n\n    {:ok, data} = Vix.Vips.Image.write_to_binary(image)\n    :binary.bin_to_list(data)\n  end\n\nbin = Thumbhash.rgba_to_thumb_hash(75, 100, :array.from_list(rgba))\n\n# Encode the data as a string (base64).\nBase.encode64(bin) # => \"k0oGLQaSVsN0BVhn2oq2Z5SQUQcZ\"\n```\n\nAs shown in the code above, you have to get the RGBA data of the image manually, as this library only performs calculations and does not handle image files.\n\nAdditionally, you cannot lose the alpha channel data. Even for non-transparent images, the alpha value must be filled in for every pixel.","ref":"readme.html#usage"},{"type":"extras","title":"Benchmark - Thumbhash","doc":"```plaintext\nName                           ips        average  deviation         median         99th %\nrgba_to_thumb_hash/3         55.17       18.13 ms    ±16.46%       16.57 ms       28.34 ms\n```","ref":"readme.html#benchmark"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}